// Copyright 2016 Orus.io. All rights reserved.

package cmd

import (
	"context"
	"fmt"
	"os"
	"time"

	"github.com/spf13/cobra"
)

var logsCmd = &cobra.Command{
	Use:   "logs",
	Short: "Logs management",
}

var logsPurgeCmd = &cobra.Command{
	Use:   "purge",
	Short: "Purge logs",
	Run: func(cmd *cobra.Command, args []string) {
		c, err := GetClient()
		if err != nil {
			return
		}
		duration, err := cmd.Flags().GetDuration("older")
		if err != nil {
			return
		}
		if duration <= 0 {
			Logger.Errorf("Please specify a positive and non-null age")
			return
		}
		before := time.Now().Add(-duration)
		Logger.Noticef("Will purged logs before %s", before)
		ctx, _ := contextCancelOnSignal(
			context.Background(), os.Interrupt,
		)
		fmt.Print("\nPurge: ")
		count, err := c.LogsPurge(ctx, before)
		if err != nil {
			Logger.Errorf("Error: %s", err)
			return
		}
		Logger.Noticef("Purged %d log entries", count)
	},
}

func init() {
	RootCmd.AddCommand(logsCmd)
	logsCmd.AddCommand(logsPurgeCmd)

	flags := logsPurgeCmd.Flags()
	flags.Duration("older", 0, "Select logs older that the passed duration")
}
