// Copyright 2016 Orus.io. All rights reserved.

package api

import (
	"fmt"

	"github.com/nats-rpc/gogo-nrpc"
)

//go:generate protoc --gogo_out=../../../.. --gogo-nrpc_out=plugins=prometheus:../../../.. --proto_path=$GOPATH/src --proto_path=$GOPATH/src/github.com/nats-rpc/gogo-nrpc --proto_path=../../xbus-api ../../xbus-api/xbus/xbus.proto
//go:generate go run ../enum-marshalers/main.go -o enum-marshalers.go Actor_Kind Actor_Status ActorProcessingState_Status LogLevel Account_Type Account_Status GraphInfo_Status Process_Status PMProcess_Status

const (
	// XbusAPIPrefix is the common prefix of all the nats subjects of the
	// xbus API.
	XbusAPIPrefix = "xbus."
)

const (
	// ActionCreate is the subject suffix for create operations
	ActionCreate = "create"
	// ActionUpdate is the subject suffix for update operations
	ActionUpdate = "update"
	// ActionDelete is the subject suffix for delete operations
	ActionDelete = "delete"
	// ActionQuery is the subject suffix for query operations
	ActionQuery = "query"

	// ServicesPrefix is the prefix for all service specific subjects
	ServicesPrefix = XbusAPIPrefix + "services."
)

// ClientProtoError returns a client error nrpc.Error
func ClientProtoError(msg string, fmtArgs ...interface{}) *nrpc.Error {
	return &nrpc.Error{
		Type:    nrpc.Error_CLIENT,
		Message: fmt.Sprintf(msg, fmtArgs...),
	}
}

// ServerProtoError returns a server error nrpc.Error
func ServerProtoError(err error) *nrpc.Error {
	return &nrpc.Error{
		Type:    nrpc.Error_SERVER,
		Message: err.Error(),
	}
}
